@@ -1,4 +1,5 @@
 CREATE TABLE func_import_task_update(
+    update_uuid VARCHAR(40) NOT NULL,
     task_uuid VARCHAR(40),
     task_status_uuid VARCHAR(40),
     title VARCHAR(1024)
@@ -13,7 +14,7 @@ FOR EACH ROW
 BEGIN
 
     SELECT debug(
-        'TRIGGER bi_func_import_task_update_1',
+        NEW.update_uuid,
         NEW.task_uuid,
         NEW.task_status_uuid,
         NEW.title
@@ -21,16 +22,22 @@ BEGIN
 
     INSERT INTO
         func_update_task(
+            update_id,
             id,
             status_id,
             title
         )
     SELECT
+        u.id,
         tasks.id,
         task_status.id,
         NEW.title
     FROM
         (SELECT 1)
+    INNER JOIN
+        updates u
+    ON
+        u.uuid = NEW.update_uuid
     LEFT JOIN
         topics AS tasks
     ON
